        function getR(rrw){
           cx=0;
       cx+=1;
       if(rrw==cx){return 3;}
       cx+=1;
       if(rrw==cx){return 17;}
       cx+=1;
       if(rrw==cx){return 19;}
       cx+=1;
       if(rrw==cx){return 20;}
       cx+=1;
       if(rrw==cx){return 21;}
       cx+=1;
       if(rrw==cx){return 22;}
return -1;}
