        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 21 <br>1,6,8,11,14,15,18,20,24,25,26,27,33,36,38,40,41,42,46,47,49';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 15 <strong>control</strong><br>0,3,5,9,10,12,13,16,21,23,28,31,37,43,50';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>2,7,19,22,34,35,39,44';}
       if(rr==4 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 7 <br>4,17,29,30,32,45,48';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 21 <br>1,6,8,11,14,15,18,20,24,25,26,27,33,36,38,40,41,42,46,47,49';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 15 <strong>control</strong><br>0,3,5,9,10,12,13,16,21,23,28,31,37,43,50';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>2,7,19,22,34,35,39,44';}
       if(rr==23 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 7 <br>4,17,29,30,32,45,48';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 21 <br>1,6,8,11,14,15,18,20,24,25,26,27,33,36,38,40,41,42,46,47,49';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 15 <strong>control</strong><br>0,3,5,9,10,12,13,16,21,23,28,31,37,43,50';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>2,7,19,22,34,35,39,44';}
       if(rr==25 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 7 <br>4,17,29,30,32,45,48';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 21 <br>1,6,8,11,14,15,18,20,24,25,26,27,33,36,38,40,41,42,46,47,49';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 15 <strong>control</strong><br>0,3,5,9,10,12,13,16,21,23,28,31,37,43,50';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>2,7,19,22,34,35,39,44';}
       if(rr==26 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 7 <br>4,17,29,30,32,45,48';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 21 <br>1,6,8,11,14,15,18,20,24,25,26,27,33,36,38,40,41,42,46,47,49';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 15 <strong>control</strong><br>0,3,5,9,10,12,13,16,21,23,28,31,37,43,50';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>2,7,19,22,34,35,39,44';}
       if(rr==27 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 7 <br>4,17,29,30,32,45,48';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 21 <br>1,6,8,11,14,15,18,20,24,25,26,27,33,36,38,40,41,42,46,47,49';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 15 <strong>control</strong><br>0,3,5,9,10,12,13,16,21,23,28,31,37,43,50';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>35</strong> miembros: 8 <br>2,7,19,22,34,35,39,44';}
       if(rr==28 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 7 <br>4,17,29,30,32,45,48';}
}
