        function getF(rr,cc){
       if(rr==4 && cc==0){return '../../SIN/096/cl0_tz_500.png';}
       if(rr==4 && cc==1){return '../../SIN/096/cl1_tz_500.png';}
       if(rr==4 && cc==2){return '../../SIN/096/cl2_tz_500.png';}
       if(rr==4 && cc==3){return '../../SIN/096/cl3_tz_500.png';}
       if(rr==4 && cc==4){return '../../SIN/096/cl4_tz_500.png';}
       if(rr==23 && cc==0){return 'prob_sf_thr1_cl0.png';}
       if(rr==23 && cc==1){return 'prob_sf_thr1_cl1.png';}
       if(rr==23 && cc==2){return 'prob_sf_thr1_cl2.png';}
       if(rr==23 && cc==3){return 'prob_sf_thr1_cl3.png';}
       if(rr==23 && cc==4){return 'prob_sf_thr1_cl4.png';}
       if(rr==25 && cc==0){return 'prob_sf_thr2_cl0.png';}
       if(rr==25 && cc==1){return 'prob_sf_thr2_cl1.png';}
       if(rr==25 && cc==2){return 'prob_sf_thr2_cl2.png';}
       if(rr==25 && cc==3){return 'prob_sf_thr2_cl3.png';}
       if(rr==25 && cc==4){return 'prob_sf_thr2_cl4.png';}
       if(rr==26 && cc==0){return 'prob_sf_thr5_cl0.png';}
       if(rr==26 && cc==1){return 'prob_sf_thr5_cl1.png';}
       if(rr==26 && cc==2){return 'prob_sf_thr5_cl2.png';}
       if(rr==26 && cc==3){return 'prob_sf_thr5_cl3.png';}
       if(rr==26 && cc==4){return 'prob_sf_thr5_cl4.png';}
       if(rr==27 && cc==0){return 'prob_sf_thr10_cl0.png';}
       if(rr==27 && cc==1){return 'prob_sf_thr10_cl1.png';}
       if(rr==27 && cc==2){return 'prob_sf_thr10_cl2.png';}
       if(rr==27 && cc==3){return 'prob_sf_thr10_cl3.png';}
       if(rr==27 && cc==4){return 'prob_sf_thr10_cl4.png';}
       if(rr==28 && cc==0){return 'prob_sf_thr20_cl0.png';}
       if(rr==28 && cc==1){return 'prob_sf_thr20_cl1.png';}
       if(rr==28 && cc==2){return 'prob_sf_thr20_cl2.png';}
       if(rr==28 && cc==3){return 'prob_sf_thr20_cl3.png';}
       if(rr==28 && cc==4){return 'prob_sf_thr20_cl4.png';}
}
